@@ -1,5 +1,5 @@
 package App::gimpgitbuild::API::GitBuild;
-$App::gimpgitbuild::API::GitBuild::VERSION = '0.0.1';
+$App::gimpgitbuild::API::GitBuild::VERSION = '0.0.2';
 use strict;
 use warnings;
 use 5.014;
@@ -18,7 +18,7 @@ App::gimpgitbuild::API::GitBuild - common API
 
 =head1 VERSION
 
-version 0.0.1
+version 0.0.2
 
 =head1 FUNCTIONS
 
@@ -45,14 +45,6 @@ L<https://metacpan.org/release/App-gimpgitbuild>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/App-gimpgitbuild>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -61,14 +53,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-gimpgitbuild>
 
 =item *
 
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/App-gimpgitbuild>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
